ApprovalRule class

Returns information about an approval rule.

Constructors

ApprovalRule({String? approvalRuleContent, String? approvalRuleId, String? approvalRuleName, DateTime? creationDate, DateTime? lastModifiedDate, String? lastModifiedUser, OriginApprovalRuleTemplate? originApprovalRuleTemplate, String? ruleContentSha256})
ApprovalRule.fromJson(Map<String, dynamic> json)
factory

Properties

approvalRuleContent → String?
The content of the approval rule.
final
approvalRuleId → String?
The system-generated ID of the approval rule.
final
approvalRuleName → String?
The name of the approval rule.
final
creationDate → DateTime?
The date the approval rule was created, in timestamp format.
final
hashCode → int
The hash code for this object.
no setterinherited
lastModifiedDate → DateTime?
The date the approval rule was most recently changed, in timestamp format.
final
lastModifiedUser → String?
The Amazon Resource Name (ARN) of the user who made the most recent changes to the approval rule.
final
originApprovalRuleTemplate → OriginApprovalRuleTemplate?
The approval rule template used to create the rule.
final
ruleContentSha256 → String?
The SHA-256 hash signature for the content of the approval rule.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited