ApprovalRuleEventMetadata class

Returns information about an event for an approval rule.

Constructors

ApprovalRuleEventMetadata({String? approvalRuleContent, String? approvalRuleId, String? approvalRuleName})
ApprovalRuleEventMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

approvalRuleContent → String?
The content of the approval rule.
final
approvalRuleId → String?
The system-generated ID of the approval rule.
final
approvalRuleName → String?
The name of the approval rule.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited