ApprovalRuleOverriddenEventMetadata class

Returns information about an override event for approval rules for a pull request.

Constructors

ApprovalRuleOverriddenEventMetadata({OverrideStatus? overrideStatus, String? revisionId})
ApprovalRuleOverriddenEventMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
overrideStatus → OverrideStatus?
The status of the override event.
final
revisionId → String?
The revision ID of the pull request when the override event occurred.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited