ApprovalRuleTemplate class

Returns information about an approval rule template.

Constructors

ApprovalRuleTemplate({String? approvalRuleTemplateContent, String? approvalRuleTemplateDescription, String? approvalRuleTemplateId, String? approvalRuleTemplateName, DateTime? creationDate, DateTime? lastModifiedDate, String? lastModifiedUser, String? ruleContentSha256})
ApprovalRuleTemplate.fromJson(Map<String, dynamic> json)
factory

Properties

approvalRuleTemplateContent → String?
The content of the approval rule template.
final
approvalRuleTemplateDescription → String?
The description of the approval rule template.
final
approvalRuleTemplateId → String?
The system-generated ID of the approval rule template.
final
approvalRuleTemplateName → String?
The name of the approval rule template.
final
creationDate → DateTime?
The date the approval rule template was created, in timestamp format.
final
hashCode → int
The hash code for this object.
no setterinherited
lastModifiedDate → DateTime?
The date the approval rule template was most recently changed, in timestamp format.
final
lastModifiedUser → String?
The Amazon Resource Name (ARN) of the user who made the most recent changes to the approval rule template.
final
ruleContentSha256 → String?
The SHA-256 hash signature for the content of the approval rule template.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited