ApprovalStateChangedEventMetadata class

Returns information about a change in the approval state for a pull request.

Constructors

ApprovalStateChangedEventMetadata({ApprovalState? approvalStatus, String? revisionId})
ApprovalStateChangedEventMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

approvalStatus → ApprovalState?
The approval status for the pull request.
final
hashCode → int
The hash code for this object.
no setterinherited
revisionId → String?
The revision ID of the pull request when the approval state changed.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited