BatchAssociateApprovalRuleTemplateWithRepositoriesError class

Returns information about errors in a BatchAssociateApprovalRuleTemplateWithRepositories operation.

Properties

errorCode → String?
An error code that specifies whether the repository name was not valid or not found.
final
errorMessage → String?
An error message that provides details about why the repository name was not found or not valid.
final
hashCode → int
The hash code for this object.
no setterinherited
repositoryName → String?
The name of the repository where the association was not made.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited