BatchDescribeMergeConflictsError class

Returns information about errors in a BatchDescribeMergeConflicts operation.

Constructors

BatchDescribeMergeConflictsError({required String exceptionName, required String filePath, required String message})
BatchDescribeMergeConflictsError.fromJson(Map<String, dynamic> json)
factory

Properties

exceptionName → String
The name of the exception.
final
filePath → String
The path to the file.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
The message provided by the exception.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited