BatchDescribeMergeConflictsOutput class

Constructors

BatchDescribeMergeConflictsOutput({required List<Conflict> conflicts, required String destinationCommitId, required String sourceCommitId, String? baseCommitId, List<BatchDescribeMergeConflictsError>? errors, String? nextToken})
BatchDescribeMergeConflictsOutput.fromJson(Map<String, dynamic> json)
factory

Properties

baseCommitId → String?
The commit ID of the merge base.
final
conflicts → List<Conflict>
A list of conflicts for each file, including the conflict metadata and the hunks of the differences between the files.
final
destinationCommitId → String
The commit ID of the destination commit specifier that was used in the merge evaluation.
final
errors → List<BatchDescribeMergeConflictsError>?
A list of any errors returned while describing the merge conflicts for each file.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
An enumeration token that can be used in a request to return the next batch of the results.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceCommitId → String
The commit ID of the source commit specifier that was used in the merge evaluation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited