BatchDisassociateApprovalRuleTemplateFromRepositoriesOutput class

Properties

disassociatedRepositoryNames → List<String>
A list of repository names that have had their association with the template removed.
final
errors → List<BatchDisassociateApprovalRuleTemplateFromRepositoriesError>
A list of any errors that might have occurred while attempting to remove the association between the template and the repositories.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited