BatchGetCommitsError class

Returns information about errors in a BatchGetCommits operation.

Constructors

BatchGetCommitsError({String? commitId, String? errorCode, String? errorMessage})
BatchGetCommitsError.fromJson(Map<String, dynamic> json)
factory

Properties

commitId → String?
A commit ID that either could not be found or was not in a valid format.
final
errorCode → String?
An error code that specifies whether the commit ID was not valid or not found.
final
errorMessage → String?
An error message that provides detail about why the commit ID either was not found or was not valid.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited