BatchGetCommitsOutput class

Constructors

BatchGetCommitsOutput({List<Commit>? commits, List<BatchGetCommitsError>? errors})
BatchGetCommitsOutput.fromJson(Map<String, dynamic> json)
factory

Properties

commits → List<Commit>?
An array of commit data type objects, each of which contains information about a specified commit.
final
errors → List<BatchGetCommitsError>?
Returns any commit IDs for which information could not be found. For example, if one of the commit IDs was a shortened SHA ID or that commit was not found in the specified repository, the ID returns an error object with more information.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited