BlobMetadata class

Returns information about a specific Git blob object.

Constructors

BlobMetadata({String? blobId, String? mode, String? path})
BlobMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

blobId → String?
The full ID of the blob.
final
hashCode → int
The hash code for this object.
no setterinherited
mode → String?
The file mode permissions of the blob. File mode permission codes include:
final
path → String?
The path to the blob and associated file name, if any.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited