Comment class

Returns information about a specific comment.

Constructors

Comment({String? authorArn, List<String>? callerReactions, String? clientRequestToken, String? commentId, String? content, DateTime? creationDate, bool? deleted, String? inReplyTo, DateTime? lastModifiedDate, Map<String, int>? reactionCounts})
Comment.fromJson(Map<String, dynamic> json)
factory

Properties

authorArn → String?
The Amazon Resource Name (ARN) of the person who posted the comment.
final
callerReactions → List<String>?
The emoji reactions to a comment, if any, submitted by the user whose credentials are associated with the call to the API.
final
clientRequestToken → String?
A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
final
commentId → String?
The system-generated comment ID.
final
content → String?
The content of the comment.
final
creationDate → DateTime?
The date and time the comment was created, in timestamp format.
final
deleted → bool?
A Boolean value indicating whether the comment has been deleted.
final
hashCode → int
The hash code for this object.
no setterinherited
inReplyTo → String?
The ID of the comment for which this comment is a reply, if any.
final
lastModifiedDate → DateTime?
The date and time the comment was most recently modified, in timestamp format.
final
reactionCounts → Map<String, int>?
A string to integer map that represents the number of individual users who have responded to a comment with the specified reactions.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited