Commit class

Returns information about a specific commit.

Constructors

Commit({String? additionalData, UserInfo? author, String? commitId, UserInfo? committer, String? message, List<String>? parents, String? treeId})
Commit.fromJson(Map<String, dynamic> json)
factory

Properties

additionalData → String?
Any other data associated with the specified commit.
final
author → UserInfo?
Information about the author of the specified commit. Information includes the date in timestamp format with GMT offset, the name of the author, and the email address for the author, as configured in Git.
final
commitId → String?
The full SHA ID of the specified commit.
final
committer → UserInfo?
Information about the person who committed the specified commit, also known as the committer. Information includes the date in timestamp format with GMT offset, the name of the committer, and the email address for the committer, as configured in Git.
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
The commit message associated with the specified commit.
final
parents → List<String>?
A list of parent commits for the specified commit. Each parent commit ID is the full commit ID.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
treeId → String?
Tree information for the specified commit.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited