ConflictMetadata class

Information about the metadata for a conflict in a merge operation.

Constructors

ConflictMetadata({bool? contentConflict, bool? fileModeConflict, FileModes? fileModes, String? filePath, FileSizes? fileSizes, IsBinaryFile? isBinaryFile, MergeOperations? mergeOperations, int? numberOfConflicts, bool? objectTypeConflict, ObjectTypes? objectTypes})
ConflictMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

contentConflict → bool?
A boolean value indicating whether there are conflicts in the content of a file.
final
fileModeConflict → bool?
A boolean value indicating whether there are conflicts in the file mode of a file.
final
fileModes → FileModes?
The file modes of the file in the source, destination, and base of the merge.
final
filePath → String?
The path of the file that contains conflicts.
final
fileSizes → FileSizes?
The file sizes of the file in the source, destination, and base of the merge.
final
hashCode → int
The hash code for this object.
no setterinherited
isBinaryFile → IsBinaryFile?
A boolean value (true or false) indicating whether the file is binary or textual in the source, destination, and base of the merge.
final
mergeOperations → MergeOperations?
Whether an add, modify, or delete operation caused the conflict between the source and destination of the merge.
final
numberOfConflicts → int?
The number of conflicts, including both hunk conflicts and metadata conflicts.
final
objectTypeConflict → bool?
A boolean value (true or false) indicating whether there are conflicts between the branches in the object type of a file, folder, or submodule.
final
objectTypes → ObjectTypes?
Information about any object type conflicts in a merge operation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited