DeleteFileEntry class

A file that is deleted as part of a commit.

Constructors

DeleteFileEntry({required String filePath})

Properties

filePath → String
The full path of the file to be deleted, including the name of the file.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited