DeleteFileOutput class

Constructors

DeleteFileOutput({required String blobId, required String commitId, required String filePath, required String treeId})
DeleteFileOutput.fromJson(Map<String, dynamic> json)
factory

Properties

blobId → String
The blob ID removed from the tree as part of deleting the file.
final
commitId → String
The full commit ID of the commit that contains the change that deletes the file.
final
filePath → String
The fully qualified path to the file to be deleted, including the full name and extension of that file.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
treeId → String
The full SHA-1 pointer of the tree information for the commit that contains the delete file change.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited