DescribeMergeConflictsOutput class

Constructors

DescribeMergeConflictsOutput({required ConflictMetadata conflictMetadata, required String destinationCommitId, required List<MergeHunk> mergeHunks, required String sourceCommitId, String? baseCommitId, String? nextToken})
DescribeMergeConflictsOutput.fromJson(Map<String, dynamic> json)
factory

Properties

baseCommitId → String?
The commit ID of the merge base.
final
conflictMetadata → ConflictMetadata
Contains metadata about the conflicts found in the merge.
final
destinationCommitId → String
The commit ID of the destination commit specifier that was used in the merge evaluation.
final
hashCode → int
The hash code for this object.
no setterinherited
mergeHunks → List<MergeHunk>
A list of merge hunks of the differences between the files or lines.
final
nextToken → String?
An enumeration token that can be used in a request to return the next batch of the results.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceCommitId → String
The commit ID of the source commit specifier that was used in the merge evaluation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited