Difference class

Returns information about a set of differences for a commit specifier.

Constructors

Difference({BlobMetadata? afterBlob, BlobMetadata? beforeBlob, ChangeTypeEnum? changeType})
Difference.fromJson(Map<String, dynamic> json)
factory

Properties

afterBlob → BlobMetadata?
Information about an afterBlob data type object, including the ID, the file mode permission code, and the path.
final
beforeBlob → BlobMetadata?
Information about a beforeBlob data type object, including the ID, the file mode permission code, and the path.
final
changeType → ChangeTypeEnum?
Whether the change type of the difference is an addition (A), deletion (D), or modification (M).
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited