Evaluation class

Returns information about the approval rules applied to a pull request and whether conditions have been met.

Constructors

Evaluation({List<String>? approvalRulesNotSatisfied, List<String>? approvalRulesSatisfied, bool? approved, bool? overridden})
Evaluation.fromJson(Map<String, dynamic> json)
factory

Properties

approvalRulesNotSatisfied → List<String>?
The names of the approval rules that have not had their conditions met.
final
approvalRulesSatisfied → List<String>?
The names of the approval rules that have had their conditions met.
final
approved → bool?
Whether the state of the pull request is approved.
final
hashCode → int
The hash code for this object.
no setterinherited
overridden → bool?
Whether the approval rule requirements for the pull request have been overridden and no longer need to be met.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited