FileMetadata class

A file to be added, updated, or deleted as part of a commit.

Constructors

FileMetadata({String? absolutePath, String? blobId, FileModeTypeEnum? fileMode})
FileMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

absolutePath → String?
The full path to the file to be added or updated, including the name of the file.
final
blobId → String?
The blob ID that contains the file information.
final
fileMode → FileModeTypeEnum?
The extrapolated file mode permissions for the file. Valid values include EXECUTABLE and NORMAL.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited