FileModes class

Information about file modes in a merge or pull request.

Constructors

FileModes({FileModeTypeEnum? base, FileModeTypeEnum? destination, FileModeTypeEnum? source})
FileModes.fromJson(Map<String, dynamic> json)
factory

Properties

base → FileModeTypeEnum?
The file mode of a file in the base of a merge or pull request.
final
destination → FileModeTypeEnum?
The file mode of a file in the destination of a merge or pull request.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → FileModeTypeEnum?
The file mode of a file in the source of a merge or pull request.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited