FileSizes class

Information about the size of files in a merge or pull request.

Constructors

FileSizes({int? base, int? destination, int? source})
FileSizes.fromJson(Map<String, dynamic> json)
factory

Properties

base → int?
The size of a file in the base of a merge or pull request.
final
destination → int?
The size of a file in the destination of a merge or pull request.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → int?
The size of a file in the source of a merge or pull request.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited