Folder class

Returns information about a folder in a repository.

Constructors

Folder({String? absolutePath, String? relativePath, String? treeId})
Folder.fromJson(Map<String, dynamic> json)
factory

Properties

absolutePath → String?
The fully qualified path of the folder in the repository.
final
hashCode → int
The hash code for this object.
no setterinherited
relativePath → String?
The relative path of the specified folder from the folder where the query originated.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
treeId → String?
The full SHA-1 pointer of the tree information for the commit that contains the folder.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited