GetDifferencesOutput class

Constructors

GetDifferencesOutput({String? nextToken, List<Difference>? differences})
GetDifferencesOutput.fromJson(Map<String, dynamic> json)
factory

Properties

differences → List<Difference>?
A data type object that contains information about the differences, including whether the difference is added, modified, or deleted (A, D, M).
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
An enumeration token that can be used in a request to return the next batch of the results.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited