GetFileOutput class

Constructors

GetFileOutput({required String blobId, required String commitId, required Uint8List fileContent, required FileModeTypeEnum fileMode, required String filePath, required int fileSize})
GetFileOutput.fromJson(Map<String, dynamic> json)
factory

Properties

blobId → String
The blob ID of the object that represents the file content.
final
commitId → String
The full commit ID of the commit that contains the content returned by GetFile.
final
fileContent → Uint8List
The base-64 encoded binary data object that represents the content of the file.
final
fileMode → FileModeTypeEnum
The extrapolated file mode permissions of the blob. Valid values include strings such as EXECUTABLE and not numeric values.
final
filePath → String
The fully qualified path to the specified file. Returns the name and extension of the file.
final
fileSize → int
The size of the contents of the file, in bytes.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited