GetFolderOutput class

Constructors

GetFolderOutput({required String commitId, required String folderPath, List<File>? files, List<Folder>? subFolders, List<SubModule>? subModules, List<SymbolicLink>? symbolicLinks, String? treeId})
GetFolderOutput.fromJson(Map<String, dynamic> json)
factory

Properties

commitId → String
The full commit ID used as a reference for the returned version of the folder content.
final
files → List<File>?
The list of files in the specified folder, if any.
final
folderPath → String
The fully qualified path of the folder whose contents are returned.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subFolders → List<Folder>?
The list of folders that exist under the specified folder, if any.
final
subModules → List<SubModule>?
The list of submodules in the specified folder, if any.
final
The list of symbolic links to other files and folders in the specified folder, if any.
final
treeId → String?
The full SHA-1 pointer of the tree information for the commit that contains the folder.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited