GetMergeConflictsOutput class

Constructors

GetMergeConflictsOutput({required List<ConflictMetadata> conflictMetadataList, required String destinationCommitId, required bool mergeable, required String sourceCommitId, String? baseCommitId, String? nextToken})
GetMergeConflictsOutput.fromJson(Map<String, dynamic> json)
factory

Properties

baseCommitId → String?
The commit ID of the merge base.
final
conflictMetadataList → List<ConflictMetadata>
A list of metadata for any conflicting files. If the specified merge strategy is FAST_FORWARD_MERGE, this list is always empty.
final
destinationCommitId → String
The commit ID of the destination commit specifier that was used in the merge evaluation.
final
hashCode → int
The hash code for this object.
no setterinherited
mergeable → bool
A Boolean value that indicates whether the code is mergeable by the specified merge option.
final
nextToken → String?
An enumeration token that can be used in a request to return the next batch of the results.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceCommitId → String
The commit ID of the source commit specifier that was used in the merge evaluation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited