GetMergeOptionsOutput class

Constructors

GetMergeOptionsOutput({required String baseCommitId, required String destinationCommitId, required List<MergeOptionTypeEnum> mergeOptions, required String sourceCommitId})
GetMergeOptionsOutput.fromJson(Map<String, dynamic> json)
factory

Properties

baseCommitId → String
The commit ID of the merge base.
final
destinationCommitId → String
The commit ID of the destination commit specifier that was used in the merge evaluation.
final
hashCode → int
The hash code for this object.
no setterinherited
mergeOptions → List<MergeOptionTypeEnum>
The merge option or strategy used to merge the code.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceCommitId → String
The commit ID of the source commit specifier that was used in the merge evaluation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited