GetPullRequestOverrideStateOutput class

Constructors

GetPullRequestOverrideStateOutput({bool? overridden, String? overrider})
GetPullRequestOverrideStateOutput.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
overridden → bool?
A Boolean value that indicates whether a pull request has had its rules set aside (TRUE) or whether all approval rules still apply (FALSE).
final
overrider → String?
The Amazon Resource Name (ARN) of the user or identity that overrode the rules and their requirements for the pull request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited