ListApprovalRuleTemplatesOutput class

Constructors

ListApprovalRuleTemplatesOutput({List<String>? approvalRuleTemplateNames, String? nextToken})
ListApprovalRuleTemplatesOutput.fromJson(Map<String, dynamic> json)
factory

Properties

approvalRuleTemplateNames → List<String>?
The names of all the approval rule templates found in the AWS Region for your AWS account.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
An enumeration token that allows the operation to batch the next results of the operation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited