ListBranchesOutput class

Represents the output of a list branches operation.

Constructors

ListBranchesOutput({List<String>? branches, String? nextToken})
ListBranchesOutput.fromJson(Map<String, dynamic> json)
factory

Properties

branches → List<String>?
The list of branch names.
final
hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
An enumeration token that returns the batch of the results.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited