ListRepositoriesForApprovalRuleTemplateOutput class

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
An enumeration token that allows the operation to batch the next results of the operation.
final
repositoryNames → List<String>?
A list of repository names that are associated with the specified approval rule template.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited