ListRepositoriesOutput class

Represents the output of a list repositories operation.

Constructors

ListRepositoriesOutput({String? nextToken, List<RepositoryNameIdPair>? repositories})
ListRepositoriesOutput.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
nextToken → String?
An enumeration token that allows the operation to batch the results of the operation. Batch sizes are 1,000 for list repository operations. When the client sends the token back to AWS CodeCommit, another page of 1,000 records is retrieved.
final
repositories → List<RepositoryNameIdPair>?
Lists the repositories called by the list repositories operation.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited