Location class

Returns information about the location of a change or comment in the comparison between two commits or a pull request.

Constructors

Location({String? filePath, int? filePosition, RelativeFileVersionEnum? relativeFileVersion})
Location.fromJson(Map<String, dynamic> json)
factory

Properties

filePath → String?
The name of the file being compared, including its extension and subdirectory, if any.
final
filePosition → int?
The position of a change in a compared file, in line number format.
final
hashCode → int
The hash code for this object.
no setterinherited
relativeFileVersion → RelativeFileVersionEnum?
In a comparison of commits or a pull request, whether the change is in the before or after of that comparison.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited