MergeBranchesByThreeWayOutput class

Constructors

MergeBranchesByThreeWayOutput({String? commitId, String? treeId})
MergeBranchesByThreeWayOutput.fromJson(Map<String, dynamic> json)
factory

Properties

commitId → String?
The commit ID of the merge in the destination or target branch.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
treeId → String?
The tree ID of the merge in the destination or target branch.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited