MergeHunkDetail class

Information about the details of a merge hunk that contains a conflict in a merge or pull request operation.

Constructors

MergeHunkDetail({int? endLine, String? hunkContent, int? startLine})
MergeHunkDetail.fromJson(Map<String, dynamic> json)
factory

Properties

endLine → int?
The end position of the hunk in the merge result.
final
hashCode → int
The hash code for this object.
no setterinherited
hunkContent → String?
The base-64 encoded content of the hunk merged region that might contain a conflict.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startLine → int?
The start position of the hunk in the merge result.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited