MergeMetadata class

Returns information about a merge or potential merge between a source reference and a destination reference in a pull request.

Constructors

MergeMetadata({bool? isMerged, String? mergeCommitId, MergeOptionTypeEnum? mergeOption, String? mergedBy})
MergeMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
isMerged → bool?
A Boolean value indicating whether the merge has been made.
final
mergeCommitId → String?
The commit ID for the merge commit, if any.
final
mergedBy → String?
The Amazon Resource Name (ARN) of the user who merged the branches.
final
mergeOption → MergeOptionTypeEnum?
The merge strategy used in the merge.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited