ObjectTypes class

Information about the type of an object in a merge operation.

Constructors

ObjectTypes({ObjectTypeEnum? base, ObjectTypeEnum? destination, ObjectTypeEnum? source})
ObjectTypes.fromJson(Map<String, dynamic> json)
factory

Properties

base → ObjectTypeEnum?
The type of the object in the base commit of the merge.
final
destination → ObjectTypeEnum?
The type of the object in the destination branch.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source → ObjectTypeEnum?
The type of the object in the source branch.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited