OriginApprovalRuleTemplate class

Returns information about the template that created the approval rule for a pull request.

Constructors

OriginApprovalRuleTemplate({String? approvalRuleTemplateId, String? approvalRuleTemplateName})
OriginApprovalRuleTemplate.fromJson(Map<String, dynamic> json)
factory

Properties

approvalRuleTemplateId → String?
The ID of the template that created the approval rule.
final
approvalRuleTemplateName → String?
The name of the template that created the approval rule.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited