PostCommentForComparedCommitOutput class

Constructors

PostCommentForComparedCommitOutput({String? afterBlobId, String? afterCommitId, String? beforeBlobId, String? beforeCommitId, Comment? comment, Location? location, String? repositoryName})
PostCommentForComparedCommitOutput.fromJson(Map<String, dynamic> json)
factory

Properties

afterBlobId → String?
In the directionality you established, the blob ID of the after blob.
final
afterCommitId → String?
In the directionality you established, the full commit ID of the after commit.
final
beforeBlobId → String?
In the directionality you established, the blob ID of the before blob.
final
beforeCommitId → String?
In the directionality you established, the full commit ID of the before commit.
final
comment → Comment?
The content of the comment you posted.
final
hashCode → int
The hash code for this object.
no setterinherited
location → Location?
The location of the comment in the comparison between the two commits.
final
repositoryName → String?
The name of the repository where you posted a comment on the comparison between commits.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited