PostCommentForPullRequestOutput class

Constructors

PostCommentForPullRequestOutput({String? afterBlobId, String? afterCommitId, String? beforeBlobId, String? beforeCommitId, Comment? comment, Location? location, String? pullRequestId, String? repositoryName})
PostCommentForPullRequestOutput.fromJson(Map<String, dynamic> json)
factory

Properties

afterBlobId → String?
In the directionality of the pull request, the blob ID of the after blob.
final
afterCommitId → String?
The full commit ID of the commit in the destination branch where the pull request is merged.
final
beforeBlobId → String?
In the directionality of the pull request, the blob ID of the before blob.
final
beforeCommitId → String?
The full commit ID of the commit in the source branch used to create the pull request, or in the case of an updated pull request, the full commit ID of the commit used to update the pull request.
final
comment → Comment?
The content of the comment you posted.
final
hashCode → int
The hash code for this object.
no setterinherited
location → Location?
The location of the change where you posted your comment.
final
pullRequestId → String?
The system-generated ID of the pull request.
final
repositoryName → String?
The name of the repository where you posted a comment on a pull request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited