PullRequest class

Returns information about a pull request.

Constructors

PullRequest({List<ApprovalRule>? approvalRules, String? authorArn, String? clientRequestToken, DateTime? creationDate, String? description, DateTime? lastActivityDate, String? pullRequestId, PullRequestStatusEnum? pullRequestStatus, List<PullRequestTarget>? pullRequestTargets, String? revisionId, String? title})
PullRequest.fromJson(Map<String, dynamic> json)
factory

Properties

approvalRules → List<ApprovalRule>?
The approval rules applied to the pull request.
final
authorArn → String?
The Amazon Resource Name (ARN) of the user who created the pull request.
final
clientRequestToken → String?
A unique, client-generated idempotency token that, when provided in a request, ensures the request cannot be repeated with a changed parameter. If a request is received with the same parameters and a token is included, the request returns information about the initial request that used that token.
final
creationDate → DateTime?
The date and time the pull request was originally created, in timestamp format.
final
description → String?
The user-defined description of the pull request. This description can be used to clarify what should be reviewed and other details of the request.
final
hashCode → int
The hash code for this object.
no setterinherited
lastActivityDate → DateTime?
The day and time of the last user or system activity on the pull request, in timestamp format.
final
pullRequestId → String?
The system-generated ID of the pull request.
final
pullRequestStatus → PullRequestStatusEnum?
The status of the pull request. Pull request status can only change from OPEN to CLOSED.
final
pullRequestTargets → List<PullRequestTarget>?
The targets of the pull request, including the source branch and destination branch for the pull request.
final
revisionId → String?
The system-generated revision ID for the pull request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
The user-defined title of the pull request. This title is displayed in the list of pull requests to other repository users.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited