PullRequestCreatedEventMetadata class

Metadata about the pull request that is used when comparing the pull request source with its destination.

Constructors

PullRequestCreatedEventMetadata({String? destinationCommitId, String? mergeBase, String? repositoryName, String? sourceCommitId})
PullRequestCreatedEventMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

destinationCommitId → String?
The commit ID of the tip of the branch specified as the destination branch when the pull request was created.
final
hashCode → int
The hash code for this object.
no setterinherited
mergeBase → String?
The commit ID of the most recent commit that the source branch and the destination branch have in common.
final
repositoryName → String?
The name of the repository where the pull request was created.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceCommitId → String?
The commit ID on the source branch used when the pull request was created.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited