PullRequestEvent class

Returns information about a pull request event.

Constructors

PullRequestEvent({String? actorArn, ApprovalRuleEventMetadata? approvalRuleEventMetadata, ApprovalRuleOverriddenEventMetadata? approvalRuleOverriddenEventMetadata, ApprovalStateChangedEventMetadata? approvalStateChangedEventMetadata, DateTime? eventDate, PullRequestCreatedEventMetadata? pullRequestCreatedEventMetadata, PullRequestEventType? pullRequestEventType, String? pullRequestId, PullRequestMergedStateChangedEventMetadata? pullRequestMergedStateChangedEventMetadata, PullRequestSourceReferenceUpdatedEventMetadata? pullRequestSourceReferenceUpdatedEventMetadata, PullRequestStatusChangedEventMetadata? pullRequestStatusChangedEventMetadata})
PullRequestEvent.fromJson(Map<String, dynamic> json)
factory

Properties

actorArn → String?
The Amazon Resource Name (ARN) of the user whose actions resulted in the event. Examples include updating the pull request with more commits or changing the status of a pull request.
final
approvalRuleEventMetadata → ApprovalRuleEventMetadata?
Information about a pull request event.
final
approvalRuleOverriddenEventMetadata → ApprovalRuleOverriddenEventMetadata?
Information about an approval rule override event for a pull request.
final
approvalStateChangedEventMetadata → ApprovalStateChangedEventMetadata?
Information about an approval state change for a pull request.
final
eventDate → DateTime?
The day and time of the pull request event, in timestamp format.
final
hashCode → int
The hash code for this object.
no setterinherited
pullRequestCreatedEventMetadata → PullRequestCreatedEventMetadata?
Information about the source and destination branches for the pull request.
final
pullRequestEventType → PullRequestEventType?
The type of the pull request event (for example, a status change event (PULL_REQUEST_STATUS_CHANGED) or update event (PULL_REQUEST_SOURCE_REFERENCE_UPDATED)).
final
pullRequestId → String?
The system-generated ID of the pull request.
final
pullRequestMergedStateChangedEventMetadata → PullRequestMergedStateChangedEventMetadata?
Information about the change in mergability state for the pull request event.
final
pullRequestSourceReferenceUpdatedEventMetadata → PullRequestSourceReferenceUpdatedEventMetadata?
Information about the updated source branch for the pull request event.
final
pullRequestStatusChangedEventMetadata → PullRequestStatusChangedEventMetadata?
Information about the change in status for the pull request event.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited