PullRequestMergedStateChangedEventMetadata class

Returns information about the change in the merge state for a pull request event.

Constructors

PullRequestMergedStateChangedEventMetadata({String? destinationReference, MergeMetadata? mergeMetadata, String? repositoryName})
PullRequestMergedStateChangedEventMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

destinationReference → String?
The name of the branch that the pull request is merged into.
final
hashCode → int
The hash code for this object.
no setterinherited
mergeMetadata → MergeMetadata?
Information about the merge state change event.
final
repositoryName → String?
The name of the repository where the pull request was created.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited