PullRequestSourceReferenceUpdatedEventMetadata class

Information about an update to the source branch of a pull request.

Constructors

PullRequestSourceReferenceUpdatedEventMetadata({String? afterCommitId, String? beforeCommitId, String? mergeBase, String? repositoryName})
PullRequestSourceReferenceUpdatedEventMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

afterCommitId → String?
The full commit ID of the commit in the source branch that was the tip of the branch at the time the pull request was updated.
final
beforeCommitId → String?
The full commit ID of the commit in the destination branch that was the tip of the branch at the time the pull request was updated.
final
hashCode → int
The hash code for this object.
no setterinherited
mergeBase → String?
The commit ID of the most recent commit that the source branch and the destination branch have in common.
final
repositoryName → String?
The name of the repository where the pull request was updated.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited