PullRequestTarget class

Returns information about a pull request target.

Constructors

PullRequestTarget({String? destinationCommit, String? destinationReference, String? mergeBase, MergeMetadata? mergeMetadata, String? repositoryName, String? sourceCommit, String? sourceReference})
PullRequestTarget.fromJson(Map<String, dynamic> json)
factory

Properties

destinationCommit → String?
The full commit ID that is the tip of the destination branch. This is the commit where the pull request was or will be merged.
final
destinationReference → String?
The branch of the repository where the pull request changes are merged. Also known as the destination branch.
final
hashCode → int
The hash code for this object.
no setterinherited
mergeBase → String?
The commit ID of the most recent commit that the source branch and the destination branch have in common.
final
mergeMetadata → MergeMetadata?
Returns metadata about the state of the merge, including whether the merge has been made.
final
repositoryName → String?
The name of the repository that contains the pull request source and destination branches.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceCommit → String?
The full commit ID of the tip of the source branch used to create the pull request. If the pull request branch is updated by a push while the pull request is open, the commit ID changes to reflect the new tip of the branch.
final
sourceReference → String?
The branch of the repository that contains the changes for the pull request. Also known as the source branch.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited