PutFileOutput class

Constructors

PutFileOutput({required String blobId, required String commitId, required String treeId})
PutFileOutput.fromJson(Map<String, dynamic> json)
factory

Properties

blobId → String
The ID of the blob, which is its SHA-1 pointer.
final
commitId → String
The full SHA ID of the commit that contains this file change.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
treeId → String
The full SHA-1 pointer of the tree information for the commit that contains this file change.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited