ReactionValueFormats class

Information about the values for reactions to a comment. AWS CodeCommit supports a limited set of reactions.

Constructors

ReactionValueFormats({String? emoji, String? shortCode, String? unicode})
ReactionValueFormats.fromJson(Map<String, dynamic> json)
factory

Properties

emoji → String?
The Emoji Version 1.0 graphic of the reaction. These graphics are interpreted slightly differently on different operating systems.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortCode → String?
The emoji short code for the reaction. Short codes are interpreted slightly differently on different operating systems.
final
unicode → String?
The Unicode codepoint for the reaction.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited