ReplaceContentEntry class

Information about a replacement content entry in the conflict of a merge or pull request operation.

Constructors

ReplaceContentEntry({required String filePath, required ReplacementTypeEnum replacementType, Uint8List? content, FileModeTypeEnum? fileMode})

Properties

content → Uint8List?
The base-64 encoded content to use when the replacement type is USE_NEW_CONTENT.
final
fileMode → FileModeTypeEnum?
The file mode to apply during conflict resoltion.
final
filePath → String
The path of the conflicting file.
final
hashCode → int
The hash code for this object.
no setterinherited
replacementType → ReplacementTypeEnum
The replacement type to use when determining how to resolve the conflict.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited