RepositoryMetadata class

Information about a repository.

Constructors

RepositoryMetadata({String? arn, String? accountId, String? cloneUrlHttp, String? cloneUrlSsh, DateTime? creationDate, String? defaultBranch, DateTime? lastModifiedDate, String? repositoryDescription, String? repositoryId, String? repositoryName})
RepositoryMetadata.fromJson(Map<String, dynamic> json)
factory

Properties

accountId → String?
The ID of the AWS account associated with the repository.
final
arn → String?
The Amazon Resource Name (ARN) of the repository.
final
cloneUrlHttp → String?
The URL to use for cloning the repository over HTTPS.
final
cloneUrlSsh → String?
The URL to use for cloning the repository over SSH.
final
creationDate → DateTime?
The date and time the repository was created, in timestamp format.
final
defaultBranch → String?
The repository's default branch name.
final
hashCode → int
The hash code for this object.
no setterinherited
lastModifiedDate → DateTime?
The date and time the repository was last modified, in timestamp format.
final
repositoryDescription → String?
A comment or description about the repository.
final
repositoryId → String?
The ID of the repository.
final
repositoryName → String?
The repository's name.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited