RepositoryNameIdPair class

Information about a repository name and ID.

Constructors

RepositoryNameIdPair({String? repositoryId, String? repositoryName})
RepositoryNameIdPair.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
repositoryId → String?
The ID associated with the repository.
final
repositoryName → String?
The name associated with the repository.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited