RepositoryTrigger class

Information about a trigger for a repository.

Constructors

RepositoryTrigger({required String destinationArn, required List<RepositoryTriggerEventEnum> events, required String name, List<String>? branches, String? customData})
RepositoryTrigger.fromJson(Map<String, dynamic> json)
factory

Properties

branches → List<String>?
The branches to be included in the trigger configuration. If you specify an empty array, the trigger applies to all branches.
final
customData → String?
Any custom data associated with the trigger to be included in the information sent to the target of the trigger.
final
destinationArn → String
The ARN of the resource that is the target for a trigger (for example, the ARN of a topic in Amazon SNS).
final
events → List<RepositoryTriggerEventEnum>
The repository events that cause the trigger to run actions in another service, such as sending a notification through Amazon SNS.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the trigger.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited