RepositoryTriggerExecutionFailure class

A trigger failed to run.

Constructors

RepositoryTriggerExecutionFailure({String? failureMessage, String? trigger})
RepositoryTriggerExecutionFailure.fromJson(Map<String, dynamic> json)
factory

Properties

failureMessage → String?
Message information about the trigger that did not run.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
trigger → String?
The name of the trigger that did not run.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited