SourceFileSpecifier class

Information about a source file that is part of changes made in a commit.

Constructors

SourceFileSpecifier({required String filePath, bool? isMove})

Properties

filePath → String
The full path to the file, including the name of the file.
final
hashCode → int
The hash code for this object.
no setterinherited
isMove → bool?
Whether to remove the source file from the parent commit.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited