SymbolicLink class

Returns information about a symbolic link in a repository folder.

Constructors

SymbolicLink({String? absolutePath, String? blobId, FileModeTypeEnum? fileMode, String? relativePath})
SymbolicLink.fromJson(Map<String, dynamic> json)
factory

Properties

absolutePath → String?
The fully qualified path to the folder that contains the symbolic link.
final
blobId → String?
The blob ID that contains the information about the symbolic link.
final
fileMode → FileModeTypeEnum?
The file mode permissions of the blob that cotains information about the symbolic link.
final
hashCode → int
The hash code for this object.
no setterinherited
relativePath → String?
The relative path of the symbolic link from the folder where the query originated.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited