Target class

Returns information about a target for a pull request.

Constructors

Target({required String repositoryName, required String sourceReference, String? destinationReference})

Properties

destinationReference → String?
The branch of the repository where the pull request changes are merged. Also known as the destination branch.
final
hashCode → int
The hash code for this object.
no setterinherited
repositoryName → String
The name of the repository that contains the pull request.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceReference → String
The branch of the repository that contains the changes for the pull request. Also known as the source branch.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited