TestRepositoryTriggersOutput class

Represents the output of a test repository triggers operation.

Constructors

TestRepositoryTriggersOutput({List<RepositoryTriggerExecutionFailure>? failedExecutions, List<String>? successfulExecutions})
TestRepositoryTriggersOutput.fromJson(Map<String, dynamic> json)
factory

Properties

failedExecutions → List<RepositoryTriggerExecutionFailure>?
The list of triggers that were not tested. This list provides the names of the triggers that could not be tested, separated by commas.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
successfulExecutions → List<String>?
The list of triggers that were successfully tested. This list provides the names of the triggers that were successfully tested, separated by commas.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited