UserInfo class

Information about the user who made a specified commit.

Constructors

UserInfo({String? date, String? email, String? name})
UserInfo.fromJson(Map<String, dynamic> json)
factory

Properties

date → String?
The date when the specified commit was commited, in timestamp format with GMT offset.
final
email → String?
The email address associated with the user who made the commit, if any.
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The name of the user who made the specified commit.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited